@@ -1,5 +1,5 @@
 import unittest
-from plapi_example import hello
+from plapi.hello_world import hello
 from io import StringIO
 import sys
 
